#
# spec file for package xmorph
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xmorph
Version:        20060817
Release:        bp156.4.10
Summary:        A morphing program
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
URL:            http://sourceforge.net/projects/xmorph/
Source:         %{name}_%{version}.tar.bz2
Source1:        %{name}.desktop
Source2:        acinclude.m4
Patch1:         xmorph-dirinfo.patch
Patch2:         xmorph-gcc_warnings.patch
Patch3:         xmorph-missing-include.patch
Patch4:         xmorph-20060817-autotools.patch
Patch5:         xmorph-automake-1.13.patch
Patch6:         xmorph-fixbuild.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  ctags
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  gtk2-devel
BuildRequires:  libtool
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xt)
Requires(post): %{install_info_prereq}
Requires(post): update-desktop-files
Requires(postun):update-desktop-files
Requires(preun):%{install_info_prereq}

%description
This morphing program reads two images in Targa format and computes the
transitions from one image to the other (arbitrarily many steps). To
avoid a simple fading effect, the program needs information about the
shapes contained in the two images. This is done by using a grid
consisting of connected checkpoints. The source grid is then
transformed into the destination grid during the morphing process.

%package devel
Summary:        Development Files For Xmorph
Group:          Productivity/Graphics/Other
Requires:       %{name} = %{version}
Requires:       glibc-devel

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%setup -q
cat %{SOURCE2} >>acinclude.m4
%patch1
%patch2
%patch3
%patch4
%patch5 -p1
%patch6 -p1

%build
autoreconf -fiv
%configure \
  --disable-static \
  --with-gtk2 \
  CFLAGS="%{optflags} -fgnu89-inline"
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%suse_update_desktop_file -i %{name} Graphics RasterGraphics
rm -r %{buildroot}%{_datadir}/xmorph/example
mkdir -p %{buildroot}%{_docdir}/xmorph/example
ln -s ../doc/packages/xmorph/example %{buildroot}%{_datadir}/xmorph/example
%find_lang %{name}
find %{buildroot} -type f -name "*.la" -delete -print

%post
/sbin/ldconfig
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
%desktop_database_post

%postun
/sbin/ldconfig
%desktop_database_postun

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files -f %{name}.lang
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/xmorph
%doc README HISTORY example
%{_mandir}/man1/*
%{_infodir}/*info*.gz
%{_libdir}/libmorph.so.*

%files devel
%{_includedir}/xmorph
%{_libdir}/libmorph.so

%changelog
* Mon Jun  7 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static)
* Thu Sep  5 2019 Marcus Meissner <meissner@suse.com>
- xmorph-fixbuild.patch: fixed build
* Mon Feb 12 2018 crrodriguez@opensuse.org
- FIx buildRequires so xorg-x11-* is not used anymore.
* Mon Dec 21 2015 mpluskal@suse.com
- Update build dependencies
- Cleanup spec file with spec-cleaner
- Use correct macros for handling of info and desktop files and
  their dependencies
* Sun Jun 21 2015 antoine.belvire@laposte.net
- Fix compilation with GCC5: add -fgnu89-inline to CFLAGS.
* Tue Mar  5 2013 pgajdos@suse.com
- builds with automake 1.13
  * automake-1.13.patch
* Mon Feb 20 2012 coolo@suse.com
- explicit buildrequires of xorg-x11-devel
* Wed Nov 16 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Mar 30 2009 crrodriguez@suse.de
- use %%find_lang
- remove static libraries and "la" files
- fix autotools stuff
- run ldconfig in the correct package
* Mon Oct 15 2007 pgajdos@suse.cz
- added missing #include <string.h>
  * missing-include.patch
* Mon Jun 25 2007 pgajdos@suse.cz
- reparing false libdir
* Fri Jun 22 2007 pgajdos@suse.cz
- splitted to xmorph and xmorph-devel
- used /sbin/ldconfig instead of %%run_ldconfig
* Fri Apr 27 2007 lmichnovic@suse.cz
- added renamed package libexpat0 into BuildRequires
* Thu Sep 14 2006 lmichnovic@suse.cz
- update to version 20060817
  French program translation update. Thanks Christophe Masson
  Corrected handling of i18n in iso environment. Thanks Thomas Huriaux
* Thu Sep  7 2006 lmichnovic@suse.cz
- building with ROM_OPT_FLAGS
- fixed ggc warning and random return data (gcc_warnings.patch)
* Mon Aug  7 2006 lmichnovic@suse.cz
- using gettextize -f to fix not expanding macro MKINSTALLDIRS
* Mon Jun 26 2006 lmichnovic@suse.cz
- added missing gcc-c++ to Buildrequires
- not removing RPM_BUILD_ROOT in install section
* Thu Jun  8 2006 sbrabec@suse.cz
- Updated to version 20060304:
  * gtk2 related fixes
  * fftw3 support
  * bug fixes
  * examples
* Thu Jun  1 2006 sbrabec@suse.cz
- Switched to gtk2 interface.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Sun Jan 11 2004 adrian@suse.de
- add %%run_ldconfig
* Fri Dec  5 2003 ltinkl@suse.cz
- update to version 20030527
- build fixes
* Fri Aug 15 2003 adrian@suse.de
- add desktop file
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Thu Mar 13 2003 ro@suse.de
- removed serial
* Sat Feb  8 2003 kukuk@suse.de
- Use install-info macros [Bug #23475]
- Add dir-info entry
* Mon Jan 13 2003 tcrhak@suse.cz
- update to version 20010220
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu May 30 2002 ro@suse.de
- fix build on lib64 platforms
* Thu Jun 21 2001 adostal@suse.cz
- upgrade to v.11sep97
- fix neededforbuild (ctags)
- fix make (depend and compile)
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Fri Mar  9 2001 ro@suse.de
- added xf86
* Wed Jun  7 2000 ro@suse.de
- fixed to compile: added -lXpm
* Fri Mar  3 2000 uli@suse.de
- moved man page to %%{_mandir}
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Oct  2 1998 ro@suse.de
- recrecate dependencies before build
* Mon Oct 20 1997 ro@suse.de
- ready for autobuild
